@@ -926,9 +926,14 @@ def time_series_tw (df):
                     restart = True
     return df 
 
-#-------------------------------------------Ratios and other advanced features----------------------------------#
+
+    #-------------------------------------------Ratios and other advanced features----------------------------------#
 def duplicates_detection(data):
     data["possible_duplicates"] = 0
+    data["close_duplicates"] = 0
+    data["group_duplicates"] = 0
+    close_duplicates_list =[]
+    group_duplicates_list = []
     for i in range(len(data)):
         if i < len(data):
             possible_duplicated = []
@@ -939,11 +944,10 @@ def duplicates_detection(data):
                     distance, path = fastdtw(list_dtw_1,list_dtw_2)
                     if (distance < 600):
                         possible_duplicated.append({"screen_name":data["screen_name"].iloc[j], "distance": distance})
-            if (len(possible_duplicated)==0):
-                possible_duplicated.append({"screen_name": "Empty", "distance": "Empty", "tw_similarity": 0,"tw_match_tw": "Empty"})   
-                data["possible_duplicates"].iloc[i] = possible_duplicated        
-            else: 
-                data["possible_duplicates"].iloc[i] = possible_duplicated          
+            close_duplicates= []
+            group_duplicates = []
+            if (len(possible_duplicated)!=0):              
+                data["possible_duplicates"].iloc[i] = possible_duplicated                        
                 for t in range(len(data["possible_duplicates"].iloc[i])):
                     #text_1 is the differences possible duplicates with the profile evaluate
                     text_1_aux = pd.DataFrame({"text":data[data["screen_name"] == data["possible_duplicates"].iloc[i][t]["screen_name"]]["text_tweets_days_list"]})
@@ -963,11 +967,24 @@ def duplicates_detection(data):
                       text_2 = list(filter(("").__ne__, text_2))  
                     comparacion = [item for item in text_2 if item in text_1]
                     if len(comparacion) > 0:
-                        data["possible_duplicates"].iloc[i][t]["tw_similarity"] = len(comparacion)/(data["num_userTw"].iloc[i])
-                        data["possible_duplicates"].iloc[i][t]["text_match_tw"] = comparacion
-                    else:
-                        data["possible_duplicates"].iloc[i][t]["tw_similarity"] = 0
-                        data["possible_duplicates"].iloc[i][t]["text_match_tw"] = "Empty"
+                        tw_similarity = len(comparacion)/(data["num_userTw"].iloc[i])
+                        if (tw_similarity > 0.3): 
+                            group_duplicates.append(data["possible_duplicates"].iloc[i][t]["screen_name"])                           
+                            close_duplicates.append({"screen_name":data["possible_duplicates"].iloc[i][t]["screen_name"], "distance": data["possible_duplicates"].iloc[i][t]["distance"],
+                                                          "tw_similarity":tw_similarity, "tw_match_tw": comparacion})
+                if len(close_duplicates) !=0:
+                    group_duplicates.append(data["screen_name"].iloc[i])
+                    group_duplicates_list.append(group_duplicates)
+                    close_duplicates_list.append(close_duplicates)
+                else:
+                    group_duplicates_list.append("Empty")
+                    close_duplicates_list.append("Empty")                    
+            else:
+              group_duplicates_list.append("Empty")
+              close_duplicates_list.append("Empty")
+    data["close_duplicates"] = close_duplicates_list
+    data["group_duplicates"] = group_duplicates_list
+    
     return data
 	
 	
@@ -1082,19 +1099,7 @@ def trend_tweets_features(data):
             data["anom_rate"].iloc[i]=0
     return data
 
-def close_duplicates(data):
-    close_duplicates_list = []
-    for i in range(len(data)):
-        close_duplicates = []
-        for j in range(len(data.iloc[i]["possible_duplicates"])):
-            if data.iloc[i]["possible_duplicates"][j]["tw_similarity"] >0.3:
-                close_duplicates.append(data.iloc[i]["possible_duplicates"][j]["screen_name"])
-        if len(close_duplicates) !=0:
-            close_duplicates_list.append(close_duplicates)
-        else:
-            close_duplicates_list.append("Empty")
-    data["close_duplicates"] = close_duplicates_list
-    return data
+
 	
 def text_to_list_features_conversor (data):
     for index, row in data.iterrows():
